pub fn parse_orderbook_quote(
msg: &BybitWsOrderbookDepthMsg,
instrument: &InstrumentAny,
ts_init: UnixNanos,
) -> Result<QuoteTick>Expand description
Parses a depth-1 order book snapshot into a [QuoteTick].
Errors
Returns an error for a different depth or message type, missing sides, or invalid price or size data.